All of lore.kernel.org
 help / color / mirror / Atom feed
From: Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
To: Linux Doc Mailing List <linux-doc@vger.kernel.org>,
	Jonathan Corbet <corbet@lwn.net>
Cc: "Mauro Carvalho Chehab" <mchehab+huawei@kernel.org>,
	"Christian König" <christian.koenig@amd.com>,
	"Alex Deucher" <alexander.deucher@amd.com>,
	"Alexander Monakov" <amonakov@ispras.ru>,
	"Aurabindo Pillai" <aurabindo.pillai@amd.com>,
	"Bhawanpreet Lakha" <Bhawanpreet.Lakha@amd.com>,
	"Daniel Vetter" <daniel@ffwll.ch>,
	"David Airlie" <airlied@linux.ie>,
	"Eryk Brol" <eryk.brol@amd.com>,
	"Harry Wentland" <harry.wentland@amd.com>,
	"Leo Li" <sunpeng.li@amd.com>,
	"Mikita Lipski" <mikita.lipski@amd.com>,
	"Nicholas Kazlauskas" <nicholas.kazlauskas@amd.com>,
	"Rodrigo Siqueira" <Rodrigo.Siqueira@amd.com>,
	"Stylon Wang" <stylon.wang@amd.com>,
	amd-gfx@lists.freedesktop.org, dri-devel@lists.freedesktop.org,
	"hersen wu" <hersenxs.wu@amd.com>,
	linux-kernel@vger.kernel.org
Subject: [PATCH v3 28/32] drm: amdgpu_dm: fix a typo
Date: Tue, 27 Oct 2020 10:51:32 +0100	[thread overview]
Message-ID: <9de495fa791596609eb2e73ba71cea99e09b2689.1603791716.git.mchehab+huawei@kernel.org> (raw)
In-Reply-To: <cover.1603791716.git.mchehab+huawei@kernel.org>

	dm_comressor_info -> dm_compressor_info

The kernel-doc markup is right, but the struct itself
and their references contain a typo.

Signed-off-by: Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
---
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c | 2 +-
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
index e2b23486ba4c..373b8481f76c 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
@@ -583,7 +583,7 @@ static void amdgpu_dm_fbc_init(struct drm_connector *connector)
 {
 	struct drm_device *dev = connector->dev;
 	struct amdgpu_device *adev = drm_to_adev(dev);
-	struct dm_comressor_info *compressor = &adev->dm.compressor;
+	struct dm_compressor_info *compressor = &adev->dm.compressor;
 	struct amdgpu_dm_connector *aconn = to_amdgpu_dm_connector(connector);
 	struct drm_display_mode *mode;
 	unsigned long max_size = 0;
-- 
2.26.2


WARNING: multiple messages have this Message-ID (diff)
From: Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
To: Linux Doc Mailing List <linux-doc@vger.kernel.org>,
	Jonathan Corbet <corbet@lwn.net>
Cc: "Stylon Wang" <stylon.wang@amd.com>,
	"Eryk Brol" <eryk.brol@amd.com>,
	"Mauro Carvalho Chehab" <mchehab+huawei@kernel.org>,
	"Alexander Monakov" <amonakov@ispras.ru>,
	"Rodrigo Siqueira" <Rodrigo.Siqueira@amd.com>,
	linux-kernel@vger.kernel.org, amd-gfx@lists.freedesktop.org,
	"Nicholas Kazlauskas" <nicholas.kazlauskas@amd.com>,
	"Leo Li" <sunpeng.li@amd.com>, "David Airlie" <airlied@linux.ie>,
	"Aurabindo Pillai" <aurabindo.pillai@amd.com>,
	"hersen wu" <hersenxs.wu@amd.com>,
	dri-devel@lists.freedesktop.org,
	"Alex Deucher" <alexander.deucher@amd.com>,
	"Mikita Lipski" <mikita.lipski@amd.com>,
	"Bhawanpreet Lakha" <Bhawanpreet.Lakha@amd.com>,
	"Christian König" <christian.koenig@amd.com>
Subject: [PATCH v3 28/32] drm: amdgpu_dm: fix a typo
Date: Tue, 27 Oct 2020 10:51:32 +0100	[thread overview]
Message-ID: <9de495fa791596609eb2e73ba71cea99e09b2689.1603791716.git.mchehab+huawei@kernel.org> (raw)
In-Reply-To: <cover.1603791716.git.mchehab+huawei@kernel.org>

	dm_comressor_info -> dm_compressor_info

The kernel-doc markup is right, but the struct itself
and their references contain a typo.

Signed-off-by: Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
---
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c | 2 +-
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
index e2b23486ba4c..373b8481f76c 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
@@ -583,7 +583,7 @@ static void amdgpu_dm_fbc_init(struct drm_connector *connector)
 {
 	struct drm_device *dev = connector->dev;
 	struct amdgpu_device *adev = drm_to_adev(dev);
-	struct dm_comressor_info *compressor = &adev->dm.compressor;
+	struct dm_compressor_info *compressor = &adev->dm.compressor;
 	struct amdgpu_dm_connector *aconn = to_amdgpu_dm_connector(connector);
 	struct drm_display_mode *mode;
 	unsigned long max_size = 0;
-- 
2.26.2

_______________________________________________
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel

WARNING: multiple messages have this Message-ID (diff)
From: Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
To: Linux Doc Mailing List <linux-doc@vger.kernel.org>,
	Jonathan Corbet <corbet@lwn.net>
Cc: "Stylon Wang" <stylon.wang@amd.com>,
	"Eryk Brol" <eryk.brol@amd.com>,
	"Mauro Carvalho Chehab" <mchehab+huawei@kernel.org>,
	"Harry Wentland" <harry.wentland@amd.com>,
	"Alexander Monakov" <amonakov@ispras.ru>,
	"Rodrigo Siqueira" <Rodrigo.Siqueira@amd.com>,
	linux-kernel@vger.kernel.org, amd-gfx@lists.freedesktop.org,
	"Nicholas Kazlauskas" <nicholas.kazlauskas@amd.com>,
	"Leo Li" <sunpeng.li@amd.com>, "David Airlie" <airlied@linux.ie>,
	"Aurabindo Pillai" <aurabindo.pillai@amd.com>,
	"hersen wu" <hersenxs.wu@amd.com>,
	dri-devel@lists.freedesktop.org,
	"Daniel Vetter" <daniel@ffwll.ch>,
	"Alex Deucher" <alexander.deucher@amd.com>,
	"Mikita Lipski" <mikita.lipski@amd.com>,
	"Bhawanpreet Lakha" <Bhawanpreet.Lakha@amd.com>,
	"Christian König" <christian.koenig@amd.com>
Subject: [PATCH v3 28/32] drm: amdgpu_dm: fix a typo
Date: Tue, 27 Oct 2020 10:51:32 +0100	[thread overview]
Message-ID: <9de495fa791596609eb2e73ba71cea99e09b2689.1603791716.git.mchehab+huawei@kernel.org> (raw)
In-Reply-To: <cover.1603791716.git.mchehab+huawei@kernel.org>

	dm_comressor_info -> dm_compressor_info

The kernel-doc markup is right, but the struct itself
and their references contain a typo.

Signed-off-by: Mauro Carvalho Chehab <mchehab+huawei@kernel.org>
---
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c | 2 +-
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
index e2b23486ba4c..373b8481f76c 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.c
@@ -583,7 +583,7 @@ static void amdgpu_dm_fbc_init(struct drm_connector *connector)
 {
 	struct drm_device *dev = connector->dev;
 	struct amdgpu_device *adev = drm_to_adev(dev);
-	struct dm_comressor_info *compressor = &adev->dm.compressor;
+	struct dm_compressor_info *compressor = &adev->dm.compressor;
 	struct amdgpu_dm_connector *aconn = to_amdgpu_dm_connector(connector);
 	struct drm_display_mode *mode;
 	unsigned long max_size = 0;
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
index 34f6369bf51f..a8a0e8cb1a11 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
@@ -86,7 +86,7 @@ struct irq_list_head {
  * @bo_ptr: Pointer to the buffer object
  * @gpu_addr: MMIO gpu addr
  */
-struct dm_comressor_info {
+struct dm_compressor_info {
 	void *cpu_addr;
 	struct amdgpu_bo *bo_ptr;
 	uint64_t gpu_addr;
@@ -148,7 +148,7 @@ struct amdgpu_dm_backlight_caps {
  * @soc_bounding_box: SOC bounding box values provided by gpu_info FW
  * @cached_state: Caches device atomic state for suspend/resume
  * @cached_dc_state: Cached state of content streams
  * @compressor: Frame buffer compression buffer. See &struct dm_comressor_info
  * @force_timing_sync: set via debugfs. When set, indicates that all connected
  *		       displays will be forced to synchronize.
  */
@@ -324,7 +324,7 @@ struct amdgpu_display_manager {
 	struct drm_atomic_state *cached_state;
 	struct dc_state *cached_dc_state;
 
-	struct dm_comressor_info compressor;
+	struct dm_compressor_info compressor;
 
 	const struct firmware *fw_dmcu;
 	uint32_t dmcu_fw_version;
@@ -148,7 +148,7 @@ struct amdgpu_dm_backlight_caps {
  * @cached_state: Caches device atomic state for suspend/resume
  * @cached_dc_state: Cached state of content streams
- * @compressor: Frame buffer compression buffer. See &struct dm_comressor_info
+ * @compressor: Frame buffer compression buffer. See &struct dm_compressor_info
  * @force_timing_sync: set via debugfs. When set, indicates that all connected
  *		       displays will be forced to synchronize.
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
index 34f6369bf51f..a8a0e8cb1a11 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
@@ -86,7 +86,7 @@ struct irq_list_head {
  * @bo_ptr: Pointer to the buffer object
  * @gpu_addr: MMIO gpu addr
  */
-struct dm_comressor_info {
+struct dm_compressor_info {
 	void *cpu_addr;
 	struct amdgpu_bo *bo_ptr;
 	uint64_t gpu_addr;
@@ -148,7 +148,7 @@ struct amdgpu_dm_backlight_caps {
  * @soc_bounding_box: SOC bounding box values provided by gpu_info FW
  * @cached_state: Caches device atomic state for suspend/resume
  * @cached_dc_state: Cached state of content streams
  * @compressor: Frame buffer compression buffer. See &struct dm_comressor_info
  * @force_timing_sync: set via debugfs. When set, indicates that all connected
  *		       displays will be forced to synchronize.
  */
@@ -324,7 +324,7 @@ struct amdgpu_display_manager {
 	struct drm_atomic_state *cached_state;
 	struct dc_state *cached_dc_state;
 
-	struct dm_comressor_info compressor;
+	struct dm_compressor_info compressor;
 
 	const struct firmware *fw_dmcu;
 	uint32_t dmcu_fw_version;
@@ -148,7 +148,7 @@ struct amdgpu_dm_backlight_caps {
  * @cached_state: Caches device atomic state for suspend/resume
  * @cached_dc_state: Cached state of content streams
- * @compressor: Frame buffer compression buffer. See &struct dm_comressor_info
+ * @compressor: Frame buffer compression buffer. See &struct dm_compressor_info
  * @force_timing_sync: set via debugfs. When set, indicates that all connected
  *		       displays will be forced to synchronize.
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
index 34f6369bf51f..a8a0e8cb1a11 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm.h
@@ -86,7 +86,7 @@ struct irq_list_head {
  * @bo_ptr: Pointer to the buffer object
  * @gpu_addr: MMIO gpu addr
  */
-struct dm_comressor_info {
+struct dm_compressor_info {
 	void *cpu_addr;
 	struct amdgpu_bo *bo_ptr;
 	uint64_t gpu_addr;
@@ -148,7 +148,7 @@ struct amdgpu_dm_backlight_caps {
  * @soc_bounding_box: SOC bounding box values provided by gpu_info FW
  * @cached_state: Caches device atomic state for suspend/resume
  * @cached_dc_state: Cached state of content streams
  * @compressor: Frame buffer compression buffer. See &struct dm_comressor_info
  * @force_timing_sync: set via debugfs. When set, indicates that all connected
  *		       displays will be forced to synchronize.
  */
@@ -324,7 +324,7 @@ struct amdgpu_display_manager {
 	struct drm_atomic_state *cached_state;
 	struct dc_state *cached_dc_state;
 
-	struct dm_comressor_info compressor;
+	struct dm_compressor_info compressor;
 
 	const struct firmware *fw_dmcu;
 	uint32_t dmcu_fw_version;
@@ -148,7 +148,7 @@ struct amdgpu_dm_backlight_caps {
  * @cached_state: Caches device atomic state for suspend/resume
  * @cached_dc_state: Cached state of content streams
- * @compressor: Frame buffer compression buffer. See &struct dm_comressor_info
+ * @compressor: Frame buffer compression buffer. See &struct dm_compressor_info
  * @force_timing_sync: set via debugfs. When set, indicates that all connected
  *		       displays will be forced to synchronize.
-- 
2.26.2

_______________________________________________
amd-gfx mailing list
amd-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/amd-gfx

  parent reply	other threads:[~2020-10-27  9:52 UTC|newest]

Thread overview: 59+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-10-27  9:51 [PATCH v3 00/32] Documentation build fixes against v5.10-rc1 Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 01/32] scripts: kernel-doc: use :c:union when needed Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 02/32] sphinx: conf.py: properly handle Sphinx 4.0 Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 03/32] docs: hwmon: adm1266.rst: fix a broken reference Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 04/32] docs: admin-guide: net.rst: add a missing blank line Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 05/32] docs: kasan.rst: add two missing blank lines Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 06/32] docs: net: statistics.rst: remove a duplicated kernel-doc Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 07/32] docs: hwmon: mp2975.rst: address some html build warnings Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 08/32] docs: userspace-api: add iommu.rst to the index file Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 09/32] blk-mq: docs: add kernel-doc description for a new struct member Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 10/32] drm: kernel-doc: document drm_dp_set_subconnector_property() params Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 11/32] drm/dp: fix kernel-doc warnings at drm_dp_helper.c Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 12/32] drm/dp: fix a kernel-doc issue at drm_edid.c Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 13/32] mm: pagemap.h: fix two kernel-doc markups Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 14/32] net: phy: remove kernel-doc duplication Mauro Carvalho Chehab
2020-10-27 12:41   ` Andrew Lunn
2020-10-27  9:51 ` [PATCH v3 15/32] crypto: sun8x-ce*: update entries to its documentation Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 16/32] ice: docs fix a devlink info that broke a table Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 17/32] MAINTAINERS: fix broken doc refs due to yaml conversion Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 18/32] docs: lockdep-design: fix some warning issues Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 19/32] locking/refcount: move kernel-doc markups to the proper place Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 20/32] IB/srpt: docs: add a description for cq_size member Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-28  3:48   ` Bart Van Assche
2020-10-28  3:48     ` Bart Van Assche
2020-10-27  9:51 ` [PATCH v3 21/32] docs: fs: api-summary.rst: get rid of kernel-doc include Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 22/32] drm: amdgpu: kernel-doc: update some adev parameters Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 23/32] jbd2: fix a kernel-doc markup Mauro Carvalho Chehab
2020-10-27 21:26   ` Theodore Y. Ts'o
2020-10-27  9:51 ` [PATCH v3 24/32] drm: drm_edid: remove a duplicated kernel-doc declaration Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 25/32] drm: kernel-doc: add description for a new function parameter Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27 10:04   ` Gerd Hoffmann
2020-10-27 10:04     ` Gerd Hoffmann
2020-10-27  9:51 ` [PATCH v3 26/32] gpu: docs: amdgpu.rst: get rid of wrong kernel-doc markups Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 27/32] drm: kernel-doc: drm_dp_helper.h: fix a typo Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` Mauro Carvalho Chehab [this message]
2020-10-27  9:51   ` [PATCH v3 28/32] drm: amdgpu_dm: " Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 29/32] selftests: kselftest_harness.h: fix kernel-doc markups Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 30/32] amdgpu: fix a few kernel-doc markup issues Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27  9:51 ` [PATCH v3 31/32] drm: drm_print.h: fix kernel-doc markups Mauro Carvalho Chehab
2020-10-27  9:51   ` Mauro Carvalho Chehab
2020-10-27 10:22   ` Daniel Vetter
2020-10-27 10:22     ` Daniel Vetter
2020-10-27  9:51 ` [PATCH v3 32/32] docs: SafeSetID: fix a warning Mauro Carvalho Chehab
2020-10-28 17:46 ` [PATCH v3 00/32] Documentation build fixes against v5.10-rc1 Jonathan Corbet

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=9de495fa791596609eb2e73ba71cea99e09b2689.1603791716.git.mchehab+huawei@kernel.org \
    --to=mchehab+huawei@kernel.org \
    --cc=Bhawanpreet.Lakha@amd.com \
    --cc=Rodrigo.Siqueira@amd.com \
    --cc=airlied@linux.ie \
    --cc=alexander.deucher@amd.com \
    --cc=amd-gfx@lists.freedesktop.org \
    --cc=amonakov@ispras.ru \
    --cc=aurabindo.pillai@amd.com \
    --cc=christian.koenig@amd.com \
    --cc=corbet@lwn.net \
    --cc=daniel@ffwll.ch \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=eryk.brol@amd.com \
    --cc=harry.wentland@amd.com \
    --cc=hersenxs.wu@amd.com \
    --cc=linux-doc@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mikita.lipski@amd.com \
    --cc=nicholas.kazlauskas@amd.com \
    --cc=stylon.wang@amd.com \
    --cc=sunpeng.li@amd.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.